<?php
/**
 * Contains functions, hooks and classes required for activating the plugin.
 * 
 * @author Paul Kashtanoff <pavelkashtanoff@gmail.com>
 * @copyright (c) 2014, OnePress
 * 
 * @since 4.0.0
 * @package sociallocker
 */

/**
 * Changes the text of the button which is shown after the success activation of the plugin. 
 * 
 * @since 3.1.0
 * @return string
 */
function sociallocker_license_manager_success_button() {
    return __('Learn how to use the plugin <i class="fa fa-lightbulb-o"></i>', 'plugin-sociallocker');
}

add_action('onp_license_manager_success_button_' . $sociallocker->pluginName, 'sociallocker_license_manager_success_button');


/**
 * Returns an URL where we should redirect a user to, after the success activation of the plugin.
 * 
 * @since 3.1.0
 * @return string
 */
function sociallocker_license_manager_success_redirect() {
    return opanda_get_admin_url('how-to-use', array('onp_sl_page' => 'sociallocker'));
}

add_action('onp_license_manager_success_redirect_' . $sociallocker->pluginName,  'sociallocker_license_manager_success_redirect');


/**
 * The activator class performing all the required actions on activation.
 * 
 * @see Factory325_Activator
 * @since 1.0.0
 */
class SocialLocker_Activation extends Factory325_Activator {
    
    /**
     * Runs activation actions.
     * 
     * @since 1.0.0
     */
    public function activate() {   
      
        $this->setupLicense();
    }
    
    /**
     * Setups the license.
     * 
     * @since 1.0.0
     */
    protected function setupLicense() {
$this->plugin->license->setDefaultLicense( array(
                'Embedded'  => '2b35dec65674314f5d8d9fe900dc03b8',
    'Key'  => '2b35dec65674314f5d8d9fe900dc03b8',
    'Category'  => 'paid',
    'Build'  => 'premium',
    'Title'  => __('OnePress Special License', 'sociallocker'),
    'Description'  => __('You are already Activated. To Change the license, Enter a key
    you received with the plugin into the form below.', 'sociallocker')       
  ));

    $this->plugin->license->setLicense( array(
    'Embedded'  => '2b35dec65674314f5d8d9fe900dc03b8',
    'Key'  => '2b35dec65674314f5d8d9fe900dc03b8',
    'Category'  => 'paid',
    'Build'  => 'premium',
    'Title'  => __('OnePress Special License', 'sociallocker'),
    'Description'  => __('You are already Activated. To Change the license, Enter a key
    you received with the plugin into the form below.', 'sociallocker')));
}
}

$sociallocker->registerActivation('SocialLocker_Activation');